##  Initiating a Synchronization Run Manually
You can initiate a synchronization run manually. This may be required when you have updated the configuration of your integration and want to verify if specific issues were fixed.
To initiate a synchronization run manually, follow these steps:
  1. In the administration area, navigate to the Integrations section.
  2. Select the integration that you need. The integration status must be Active.
  3. To go to the configuration page, click Configure.
  4. Click Run Sync (Trigger Synchronization).


A new synchronization run starts. You can check the progress in the Synchronization Logging section.
To cancel a synchronization run in progress, on the Synchronization Logging page, click Cancel Sync under Actions. For some integration types, this option is not available.
![Canceling a synchronization run in progress](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c36a17a4410149c8ea1a7c45fc6cf_LowRes.png)
Canceling a Synchronization Run in Progress
